# -*- coding: utf-8 -*-
# Copyright (c) 2023 Zetaloop
# See LICENSE.md for details.

"""
Alternative pin mappings for Orange PI Zero 2W
(see https://drive.google.com/drive/folders/1tyaEemq5COwmbvGT7v_cfKhg2_t4u_yg for schematic)
Usage:
.. code:: python
   import orangepi.zero2w
   from OPi import GPIO
   GPIO.setmode(orangepi.zero2w.BOARD) or GPIO.setmode(orangepi.zero2w.BCM)
"""

# Orange Pi Zero 2W physical board pin to GPIO pin
BOARD = {
    3: 264,  # PI8/RGMII_TXD2/RMII_NULL/UART2_CTS/TS0_DVLD/TWI1_SDA/PI_EINT8
    5: 263,  # PI7/RGMII_TXD3/RMII_NULL/UART2_RTS/TS0_SYNC/TWI1_SCK/PI_EINT7
    7: 269,  # PI13/RGMII_CLKIN/RMII_NULL/UART4_TX/TS0_D4/PWM3/PI_EINT13
    8: 224,  # PH0/UART0_TX/CAN_TX/PWM3/TWI1_SCK/PH_EINT0
    10: 225,  # PH1/UART0_RX/CAN_RX/PWM4/TWI1_SDA/PH_EINT1
    11: 226,  # PH2/UART5_TX/SPDIF_CLK/PWM2/TWI2_SCK/PH_EINT2/EPHY-SPD-LED
    12: 257,  # PI1/RGMII_RXD2/RMII_NULL/DMIC_DATA0/H_I2S0_BCLK/HDMI_SDA/PI_EINT1
    13: 227,  # PH3/UART5_RX/SPDIF_IN/PWM1/TWI2_SDA/PH_EINT3/EPHY-LINK-LED
    15: 261,  # PI5/RGMII_RXCTL/RMII_CRS_DV/UART2_TX/TS0_CLK/TWI0_SCK/PI_EINT5
    16: 270,  # PI14/MDC/UART4_RX/TS0_D5/PWM4/PI_EINT14
    18: 228,  # PH4/SPDIF_OUT/TWI3_SCK/PH_EINT4
    19: 231,  # PH7/UART2_RTS/H_I2S3_LRCK/SPI1_MOSI/TWI4_SDA/PH_EINT7
    21: 232,  # PH8/UART2_CTS/H_I2S3_DOUT0/SPI1_MISO/H_I2S3_DIN1/PH_EINT8
    22: 262,  # PI6/RGMII_NULL/RMII_RXER/UART2_RX/TS0_ERR/TWI0_SDA/PI_EINT6
    23: 230,  # PH6/UART2_RX/H_I2S3_BCLK/SPI1_CLK/TWI4_SCK/PH_EINT6
    24: 229,  # PH5/UART2_TX/H_I2S3_MCLK/SPI1_CS0/TWI3_SDA/PH_EINT5
    26: 233,  # PH9/H_I2S3_DIN0/SPI1_CS1/H_I2S3_DOUT1/PH_EINT9
    27: 266,  # PI10/RGMII_TXD0/RMII_TXD0/UART3_RX/TS0_D1/TWI2_SDA/PI_EINT10
    28: 265,  # PI9/RGMII_TXD1/RMII_TXD1/UART3_TX/TS0_D0/TWI2_SCK/PI_EINT9
    29: 256,  # PI0/RGMII_RXD3/RMII_NULL/DMIC_CLK/H_I2S0_MCLK/HDMI_SCL/PI_EINT0
    31: 271,  # PI15/MDIO/UART4_RTS/TS0_D6/CLK_FANOUT0/PI_EINT15
    32: 267,  # PI11/RGMII_TXCK/RMII_TXCK/UART3_RTS/TS0_D2/PWM1/PI_EINT11
    33: 268,  # PI12/RGMII_TXCTL/RMII_TXEN/UART3_CTS/TS0_D3/PWM2/PI_EINT12
    35: 258,  # PI2/RGMII_RXD1/RMII_RXD1/DMIC_DATA1/H_I2S0_LRCK/HDMI_CEC/PI_EINT2
    36: 76,  # PC12/NAND_DQS/PC_EINT12
    37: 272,  # PI16/EPHY_25M/UART4_CTS/TS0_D7/CLK_FANOUT1/PI_EINT16
    38: 260,  # PI4/RGMII_RXCK/RMII_NULL/DMIC_DATA3/H_I2S0_DIN0/H_I2S0_DOUT1/PI_EINT4
    40: 259,  # PI3/RGMII_RXD0/RMII_RXD0/DMIC_DATA2/H_I2S0_DOUT0/H_I2S0_DIN1/PI_EINT3
}

# Orange Pi Zero 2W BCM pin to GPIO pin
# For compatibility with RPi
BCM = {
    2: BOARD[3],
    3: BOARD[5],
    4: BOARD[7],
    14: BOARD[8],
    15: BOARD[10],
    17: BOARD[11],
    18: BOARD[12],
    27: BOARD[13],
    22: BOARD[15],
    23: BOARD[16],
    24: BOARD[18],
    10: BOARD[19],
    9: BOARD[21],
    25: BOARD[22],
    11: BOARD[23],
    8: BOARD[24],
    7: BOARD[26],
    0: BOARD[27],
    1: BOARD[28],
    5: BOARD[29],
    6: BOARD[31],
    12: BOARD[32],
    13: BOARD[33],
    19: BOARD[35],
    16: BOARD[36],
    26: BOARD[37],
    20: BOARD[38],
    21: BOARD[40],
}
